==> viha-5.15.tar.gz: viha-5.15/alue.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "alue";
$file = basename(__FILE__);

include "common.php";
include "alue-ok.php";

echo "
<html>
<head>
 <title>VIHA - Alueet</title>
</head>
" . body_bgcolor() . "
<h1>Alueiden ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue = get_txt('alue');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_0($file);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = alue_add_ok($herja,$alue);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue = '$alue',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = alue_save_ok($herja,$id,$alue);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue = '$alue',
           ts = '$now'
       WHERE id = $id";
    $result = my_mysql_query ($sql,true,true);
    print "<p>Tiedot pivitetty.\n";
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = alue_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql,true,true);
    # silently update the man-hour table as well
    $sql =
      "UPDATE hlo_ajat
       SET variable_id = 1
       WHERE variable_id = $id AND hlo_ajat_tyyppi_id = 3";
    my_mysql_query ($sql,true,true);
    print "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
  $id = '0';
  $alue = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = alue_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue = $a['alue'];
 }

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Alue:";
if ($readonly) {
  print "<td>$alue\n";
} else {
  print "<td><input type=\"text\" name=\"alue\" size=64 maxlength=64";
  print " value=\"$alue\">\n";
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql =
  "SELECT $table.id, $table.alue, $table.ts
   FROM $table
   ORDER BY $table.alue";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Alue\n";
  while ($a = mysql_fetch_array($result)) {
    echo "<TR><TD>$a[id]", "<TD>$a[ts]", "<TD>$a[alue]";
    if ($id == 0 && $a['id'] > 3) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<p>Plop. Ei alueita.";
}

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: alue.php,v 1.5 2009/06/06 14:12:17 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/alue.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "alue";
$file = basename(__FILE__);

include "common.php";
include "alue-ok.php";

echo "
<html>
<head>
 <title>VIHA - Alueet</title>
</head>
" . body_bgcolor() . "
<h1>Alueiden ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue = get_txt('alue');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_0($file);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = alue_add_ok($herja,$alue);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue = '$alue',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = alue_save_ok($herja,$id,$alue);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue = '$alue',
           ts = '$now'
       WHERE id = $id";
    $result = my_mysql_query ($sql,true,true);
    print "<p>Tiedot pivitetty.\n";
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = alue_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql,true,true);
    # silently update the man-hour table as well
    $sql =
      "UPDATE hlo_ajat
       SET variable_id = 1
       WHERE variable_id = $id AND hlo_ajat_tyyppi_id = 3";
    my_mysql_query ($sql,true,true);
    print "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
  $id = '0';
  $alue = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = alue_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue = $a['alue'];
 }

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Alue:";
if ($readonly) {
  print "<td>$alue\n";
} else {
  print "<td><input type=\"text\" name=\"alue\" size=64 maxlength=64";
  print " value=\"$alue\">\n";
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql =
  "SELECT $table.id, $table.alue, $table.ts
   FROM $table
   ORDER BY $table.alue";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Alue\n";
  while ($a = mysql_fetch_array($result)) {
    echo tr() . "<TD>$a[id]", "<TD>$a[ts]", "<TD>$a[alue]";
    if ($id == 0 && $a['id'] > 3) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<p>Plop. Ei alueita.";
}

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: alue.php,v 1.6 2009/09/29 16:09:14 riku Exp $ -->
